﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.DataImporter.Command {
  [StorableClass]
  [ViewableCommandInfoAttribute("Delete ColumnGroup", 1, ColumnGroupState.Active, "ColumnGroup Commands", Position = 1)]
  public class DeleteColumnGroupCommand : DataSetCommandWithAffectedColumnGroupsBase {
    private List<KeyValuePair<int, ColumnGroup>> deletedColumnGroups;

    private DeleteColumnGroupCommand()
      : base(null, null) {
      deletedColumnGroups = new List<KeyValuePair<int, ColumnGroup>>();
    }

    public DeleteColumnGroupCommand(DataSet dataSet, List<string> affectedColumnGroupNames)
      : base(dataSet, affectedColumnGroupNames) {
      deletedColumnGroups = new List<KeyValuePair<int, ColumnGroup>>();
    }

    public override string Description {
      get { return "Delete ColumnGroup"; }
    }

    public override void Execute() {
      base.Execute();
      ColumnGroup columnGroup;
      foreach (string columnGroupName in AffectedColumnGroupNames) {
        columnGroup = this.DataSet.GetColumnGroup(columnGroupName);
        deletedColumnGroups.Add(new KeyValuePair<int, ColumnGroup>(this.DataSet.IndexOfColumnGroup(columnGroup), columnGroup));
        this.DataSet.RemoveColumnGroup(columnGroup);
      }
      this.DataSet.FireChanged();
    }

    public override void UndoExecute() {
      base.UndoExecute();
      for (int i = 0; i < deletedColumnGroups.Count; i++)
        this.DataSet.InsertColumnGroup(deletedColumnGroups[i].Key, deletedColumnGroups[i].Value);
      deletedColumnGroups.Clear();
      this.DataSet.FireChanged();
    }
  }
}
