﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using System.Windows.Forms;

namespace HeuristicLab.DataImporter.Command {
  [StorableClass]
  [ViewableCommandInfo("Merge ColumnGroups", 2, ColumnGroupState.Active, "ColumnGroup Commands", Position = 5, MinActiveColumnGroups = 2)]
  public class MergeColumnGroupsCommand : DataSetCommandWithAffectedColumnGroupsBase {
    private SortedDictionary<int, ColumnGroup> oldColumnGroups;
    private List<int> oldRowCounts;
    private ColumnGroup newColumnGroup;

    private MergeColumnGroupsCommand()
      : base(null, null) {
      oldColumnGroups = new SortedDictionary<int, ColumnGroup>();
      oldRowCounts = new List<int>();
    }

    public MergeColumnGroupsCommand(DataSet dataSet, List<string> affectedColumnGroupNames)
      : base(dataSet, affectedColumnGroupNames) {
      oldColumnGroups = new SortedDictionary<int, ColumnGroup>();
      oldRowCounts = new List<int>();
    }

    public override void Execute() {
      base.Execute();
      string name = "";
      ColumnGroup columnGroup;
      foreach (string columnGroupName in AffectedColumnGroupNames) {
        columnGroup = this.DataSet.GetColumnGroup(columnGroupName);
        oldColumnGroups.Add(this.DataSet.IndexOfColumnGroup(columnGroup), columnGroup);
        oldRowCounts.Add(columnGroup.RowCount);
        name = name + " & " + columnGroup.Name;
      }
      name = name.Remove(0, 3);
      this.newColumnGroup = new ColumnGroup(name);
      foreach (ColumnGroup grp in oldColumnGroups.Values) {
        newColumnGroup.AddColumns(grp.Columns);
        DataSet.RemoveColumnGroup(grp);
      }

      foreach (ColumnBase col in this.newColumnGroup.Columns) {
        col.Resize(oldRowCounts.Max());
        col.SortOrder = SortOrder.None;
      }
      DataSet.InsertColumnGroup(oldColumnGroups.Keys.ElementAt(0), this.newColumnGroup);
      DataSet.FireChanged();
    }

    public override void UndoExecute() {
      base.UndoExecute();
      DataSet.RemoveColumnGroup(newColumnGroup);
      int col;
      for (int i = 0; i < oldColumnGroups.Count; i++) {
        col = oldColumnGroups.Keys.ElementAt(i);
        DataSet.InsertColumnGroup(col, oldColumnGroups[col]);
        foreach (ColumnBase column in oldColumnGroups[col].Columns)
          column.Resize(oldRowCounts[i]);
      }
      oldColumnGroups.Clear();
      newColumnGroup = null;
      oldRowCounts.Clear();
      DataSet.FireChanged();
    }

    public override string Description {
      get { return "Merge column groups"; }
    }
  }
}
