﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;


namespace HeuristicLab.DataImporter.Command {
  [StorableClass]
  [ViewableCommandInfoAttribute("Move ColumnGroup left", 1, ColumnGroupState.Active, "ColumnGroup Commands", Position = 2)]
  public class MoveColumnGroupLeftCommand : DataSetCommandWithAffectedColumnGroupsBase {
    private MoveColumnGroupLeftCommand()
      : base(null, null) {
    }
    public MoveColumnGroupLeftCommand(DataSet dataSet, List<string> affectedColumnGroups)
      : base(dataSet, affectedColumnGroups) {
    }

    public override string Description {
      get { return "Move column group left"; }
    }

    public override void Execute() {
      base.Execute();
      ColumnGroup cg = this.DataSet.GetColumnGroup(AffectedColumnGroupNames[0]);
      int columnGroupIndex = DataSet.IndexOfColumnGroup(cg);
      if (columnGroupIndex != 0) {
        DataSet.RemoveColumnGroup(cg);
        DataSet.InsertColumnGroup(columnGroupIndex - 1, cg);
        DataSet.FireChanged();
      }
    }

    public override void UndoExecute() {
      base.UndoExecute();
      ColumnGroup cg = this.DataSet.GetColumnGroup(this.AffectedColumnGroupNames[0]);
      int columnGroupIndex = this.DataSet.IndexOfColumnGroup(cg);
      if (columnGroupIndex != this.DataSet.ColumnGroups.Count() - 1) {
        DataSet.RemoveColumnGroup(cg);
        DataSet.InsertColumnGroup(columnGroupIndex + 1, cg);
        DataSet.FireChanged();
      }
      this.DataSet.FireChanged();
    }
  }
}