﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;


namespace HeuristicLab.DataImporter.Command {
  [StorableClass]
  [ViewableCommandInfoAttribute("Move ColumnGroup right", 1, ColumnGroupState.Active, "ColumnGroup Commands", Position = 3)]
  public class MoveColumnGroupRightCommand : DataSetCommandWithAffectedColumnGroupsBase {
    private MoveColumnGroupRightCommand()
      : base(null, null) {
    }

    public MoveColumnGroupRightCommand(DataSet dataSet, List<string> affectedColumnGroups)
      : base(dataSet, affectedColumnGroups) {
    }

    public override string Description {
      get { return "Move column group right"; }
    }

    public override void Execute() {
      base.Execute();
      ColumnGroup cg = this.DataSet.GetColumnGroup(AffectedColumnGroupNames[0]);
      int columnGroupIndex = DataSet.IndexOfColumnGroup(cg);
      if (columnGroupIndex != DataSet.ColumnGroups.Count() - 1) {
        DataSet.RemoveColumnGroup(cg);
        DataSet.InsertColumnGroup(columnGroupIndex + 1, cg);
        DataSet.FireChanged();
      }
    }

    public override void UndoExecute() {
      base.UndoExecute();
      ColumnGroup cg = this.DataSet.GetColumnGroup(AffectedColumnGroupNames[0]);
      int columnGroupIndex = DataSet.IndexOfColumnGroup(cg);
      if (columnGroupIndex == 0) {
        DataSet.RemoveColumnGroup(cg);
        DataSet.InsertColumnGroup(columnGroupIndex - 1, cg);
        DataSet.FireChanged();
      }
      this.DataSet.FireChanged();
    }
  }
}