﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.DataImporter.Command {
  [StorableClass]
  [ViewableCommandInfo("Split ColumnGroup", 1, ColumnGroupState.ColumnSelected, "ColumnGroup Commands", Position = 6, SelectedColumns = 2)]
  public class SplitColumnGroupsCommand : ColumnGroupCommandWithAffectedColumnsBase {
    private IEnumerable<SortOrder> oldSortOrder;
    private ColumnGroup oldColumnGroup;
    private int oldColumnGroupIndex;
    private ColumnGroup newColumnGroup1;
    private ColumnGroup newColumnGroup2;

    private SplitColumnGroupsCommand()
      : base(null, string.Empty, null) {
    }

    public SplitColumnGroupsCommand(DataSet dataSet, string columnGroupName, int[] affectedColumns)
      : base(dataSet, columnGroupName, affectedColumns) {
    }

    public override void Execute() {
      base.Execute();
      int splitPosition = AffectedColumns[0] + 1;
      oldColumnGroup = this.ColumnGroup;
      oldColumnGroupIndex = this.DataSet.IndexOfColumnGroup(oldColumnGroup);
      oldSortOrder = oldColumnGroup.SortOrdersForColumns.ToList();
      newColumnGroup1 = new ColumnGroup(oldColumnGroup.Name);
      newColumnGroup2 = new ColumnGroup(oldColumnGroup.Name);

      for (int i = 0; i < splitPosition; i++)
        newColumnGroup1.AddColumn(oldColumnGroup.Columns.ElementAt(i));
      for (int i = splitPosition; i < oldColumnGroup.Columns.Count(); i++)
        newColumnGroup2.AddColumn(oldColumnGroup.Columns.ElementAt(i));

      newColumnGroup1.ResetSorting();
      newColumnGroup2.ResetSorting();
      this.DataSet.RemoveColumnGroup(oldColumnGroup);
      this.DataSet.InsertColumnGroup(oldColumnGroupIndex, newColumnGroup1);
      this.DataSet.InsertColumnGroup(oldColumnGroupIndex + 1, newColumnGroup2);
      this.DataSet.FireChanged();
    }

    public override void UndoExecute() {
      base.UndoExecute();
      this.DataSet.RemoveColumnGroup(newColumnGroup1);
      this.DataSet.RemoveColumnGroup(newColumnGroup2);
      this.DataSet.InsertColumnGroup(oldColumnGroupIndex, oldColumnGroup);
      oldColumnGroup.SortOrdersForColumns = oldSortOrder;
      newColumnGroup1 = null;
      newColumnGroup2 = null;
      oldSortOrder = null;
      oldColumnGroup = null;
      this.DataSet.FireChanged();
    }

    public override string Description {
      get { return "Split column group"; }
    }
  }
}